import customtkinter as ctk
import requests
from PIL import Image, ImageTk
from tkinter import messagebox
import io

SHOPPING = "#00c1ff"
DARK_BG = "#1f1f1f"
CARD_BG = "#2b2b2b"
BACKEND_HOST = "http://127.0.0.1:8000"

def fix_url(url):
    if url.startswith("http"):
        return url
    prefix = "app/static/"
    if url.startswith(prefix):
        url = url[len(prefix):]
    return f"{BACKEND_HOST}/static/{url}"

def user_orders_frame(parent, switch_func, API_URL, token):
    """
    A modern user orders page that displays the products the user has purchased
    along with associated shop details.
    """
    # Main container frame with dark background
    frame = ctk.CTkFrame(parent, fg_color=DARK_BG)

    # --- TOP BAR ---
    top_bar = ctk.CTkFrame(frame, fg_color=SHOPPING, height=50)
    top_bar.pack(fill="x", side="top")

    top_label = ctk.CTkLabel(
        top_bar, 
        text="My Orders", 
        text_color="white", 
        font=("Helvetica", 20, "bold")
    )
    top_label.pack(side="left", padx=25)

    def go_back():
        switch_func("dashboard")

    back_button = ctk.CTkButton(
        top_bar,
        text="← Back",
        fg_color="transparent",
        text_color="white",
        hover_color="#0096ff",
        command=go_back,
        width=80,
        height=35,
        font=("Helvetica", 14)
    )
    back_button.pack(side="right", padx=20, pady=7)

    # --- MAIN SECTION: Sidebar + Content ---
    main_section = ctk.CTkFrame(frame, fg_color="transparent")
    main_section.pack(fill="both", expand=True)

    # LEFT SIDEBAR
    sidebar_frame = ctk.CTkFrame(main_section, width=250, fg_color=CARD_BG, corner_radius=15)
    sidebar_frame.pack(side="left", fill="y", padx=20, pady=20)
    sidebar_frame.pack_propagate(False)

    sidebar_title = ctk.CTkLabel(
        sidebar_frame, 
        text="Menu", 
        font=("Helvetica", 18, "bold"), 
        text_color=SHOPPING
    )
    sidebar_title.pack(pady=(20, 10))

    def create_nav_button(text, command=None, is_active=False):
        return ctk.CTkButton(
            sidebar_frame,
            text=text,
            fg_color="transparent",
            text_color="white",
            hover_color="#3b3b3b",
            command=command,
            height=40,
            font=("Helvetica", 14),
            state="disabled" if is_active else "normal"
        )

    nav_dashboard = create_nav_button("Dashboard", go_back)
    nav_dashboard.pack(fill="x", padx=15, pady=5)

    def open_profile():
        switch_func("user_details")

    nav_profile = create_nav_button("My Profile", open_profile)
    nav_profile.pack(fill="x", padx=15, pady=5)

    nav_orders = create_nav_button("My Orders", is_active=True)
    nav_orders.pack(fill="x", padx=15, pady=5)

    def open_payments():
        switch_func("user_payments")

    nav_payments = create_nav_button("My Payments", open_payments)
    nav_payments.pack(fill="x", padx=15, pady=5)

    become_owner = create_nav_button("Become Shop Owner", lambda: switch_func("create_shop"))
    become_owner.pack(fill="x", padx=15, pady=5)

    # RIGHT CONTENT
    content_frame = ctk.CTkFrame(main_section, fg_color=CARD_BG, corner_radius=15)
    content_frame.pack(side="left", fill="both", expand=True, padx=(0, 20), pady=20)

    # ORDER HISTORY
    orders_frame = ctk.CTkScrollableFrame(content_frame, fg_color="transparent")
    orders_frame.pack(fill="both", expand=True, padx=20, pady=20)

    # Header for orders
    header_label = ctk.CTkLabel(
        orders_frame,
        text="Your Order History",
        font=("Helvetica", 18, "bold"),
        text_color=SHOPPING
    )
    header_label.pack(anchor="w", pady=(0, 20))

    def load_order_history():
        # Clear existing items
        for widget in orders_frame.winfo_children()[1:]:  # Keep the header
            widget.destroy()

        try:
            headers = {"Authorization": f"Bearer {token}"}
            response = requests.get(f"{API_URL}/orders/list", headers=headers)
            
            if response.status_code == 200:
                orders = response.json()
                
                if not orders:
                    empty_label = ctk.CTkLabel(
                        orders_frame,
                        text="You haven't placed any orders yet",
                        font=("Helvetica", 14)
                    )
                    empty_label.pack(pady=20)
                    return

                for order in orders:
                    order_frame = create_order_history_frame(order)
                    order_frame.pack(fill="x", pady=10)

            else:
                error_msg = response.json().get("detail", "Unknown error")
                messagebox.showerror("Error", f"Failed to load orders: {error_msg}")

        except Exception as e:
            messagebox.showerror("Error", f"Failed to load order history: {str(e)}")

    def create_order_history_frame(order):
        order_frame = ctk.CTkFrame(orders_frame, fg_color=CARD_BG, corner_radius=10)
        
        # Order header
        header_frame = ctk.CTkFrame(order_frame, fg_color="#212121", corner_radius=5)
        header_frame.pack(fill="x", padx=10, pady=(10, 0))
        
        # Order ID and date
        order_id = order.get("id", "Unknown")
        created_at = order.get("created_at", "Unknown date")
        if isinstance(created_at, str) and len(created_at) > 10:
            created_at = created_at[:10]  # Just get the date part
            
        header_text = f"Order #{order_id} - {created_at}"
        ctk.CTkLabel(
            header_frame,
            text=header_text,
            font=("Helvetica", 14, "bold")
        ).pack(side="left", padx=10, pady=5)
        
        # Order status
        status = order.get("status", "unknown").upper()
        status_colors = {
            "PENDING": "#FFA500",
            "PROCESSING": "#4169E1",
            "SHIPPED": "#9370DB",
            "DELIVERED": "#32CD32",
            "COMPLETED": "#32CD32",
            "CANCELLED": "#DC143C"
        }
        status_color = status_colors.get(status, "#808080")
        
        ctk.CTkLabel(
            header_frame,
            text=status,
            font=("Helvetica", 14, "bold"),
            text_color=status_color
        ).pack(side="right", padx=10, pady=5)
        
        # Order details
        details_frame = ctk.CTkFrame(order_frame, fg_color="transparent")
        details_frame.pack(fill="x", padx=10, pady=10)
        
        # Delivery address
        address_frame = ctk.CTkFrame(details_frame, fg_color="transparent")
        address_frame.pack(fill="x", pady=5)
        
        ctk.CTkLabel(
            address_frame,
            text="Delivery Address:",
            font=("Helvetica", 12, "bold"),
            text_color="#AAAAAA"
        ).pack(side="left", padx=(10, 5))
        
        ctk.CTkLabel(
            address_frame,
            text=order.get("delivery_address", "No address provided"),
            font=("Helvetica", 12),
            text_color="white"
        ).pack(side="left")
        
        # Totals
        totals_frame = ctk.CTkFrame(details_frame, fg_color="transparent")
        totals_frame.pack(fill="x", pady=5)
        
        # Shipping price
        shipping_frame = ctk.CTkFrame(totals_frame, fg_color="transparent")
        shipping_frame.pack(fill="x")
        
        ctk.CTkLabel(
            shipping_frame,
            text="Shipping:",
            font=("Helvetica", 12, "bold"),
            text_color="#AAAAAA"
        ).pack(side="left", padx=(10, 5))
        
        shipping_price = order.get("shipping_price", 0)
        ctk.CTkLabel(
            shipping_frame,
            text=f"₫{shipping_price:,.0f}",
            font=("Helvetica", 12),
            text_color="white"
        ).pack(side="left")
        
        # Total price
        total_frame = ctk.CTkFrame(totals_frame, fg_color="transparent")
        total_frame.pack(fill="x")
        
        ctk.CTkLabel(
            total_frame,
            text="Total:",
            font=("Helvetica", 14, "bold"),
            text_color="#AAAAAA"
        ).pack(side="left", padx=(10, 5))
        
        total_price = order.get("total_price", 0)
        ctk.CTkLabel(
            total_frame,
            text=f"₫{total_price:,.0f}",
            font=("Helvetica", 14, "bold"),
            text_color=SHOPPING
        ).pack(side="left")
        
        return order_frame

    # Load orders when the frame is created
    load_order_history()
    
    return frame
